# The Mathematics Package 0.0.0a1
[![CI](https://github.com/arihant2math/mathematics/actions/workflows/test.yml/badge.svg)](https://github.com/arihant2math/mathematics/actions/workflows/test.yml)
[![Documentation Status](https://readthedocs.org/projects/mathematics-package/badge/?version=latest)](https://mathematics-package.readthedocs.io/en/latest/?badge=latest)

A mathematics package that aims to cover most mathematical use cases of python that are not implemented in the
[standard library](https://docs.python.org/3/library/).